/*
TmxViewer is a TMX file reader
Copyright (C) 2004 Yoan BLANC <Yoan.Blanc@eiaj.ch>, EIAJ www.eiaj.ch

This program is free software; you can redistribute it and/or modify it under the terms of
the GNU General Public License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA 02111-1307 USA
*/
/**
 * Reprsentation objet d'un fichier TMX.
 *
 * @author	Yoan BLANC
 */
import org.jdom.*;
import org.jdom.input.*;
import java.io.*;
import java.util.List;
import javax.swing.*;

public class FichierTmx implements Fichier {
	/**
	 *  Tableau de documents.
	 */
	private DocumentLang[] textes;
	/**
	 *  Entte du fichier TMX
	 */
	private Header head;
	/**
	 * lment parent.
	 */
	private JFrame parent;
	
	/**
	 * Constructeur vide (il faut construire avec ouvrir() par la suite)
	 */
	public FichierTmx(JFrame parent)
	{
		this.parent = parent;
		head = new Header();
	}
	
	/**
	 * Constructeur  partir d'une adresse.
	 *
	 *  @param	chemin	adresse du fichier  ouvrir
	 */
	public FichierTmx(JFrame parent, String chemin)
	{
		this(parent);
		ouvrir(chemin);
	}
	
	/**
	 * Construit le document TMX via un fichier.
	 *
	 *  @see Fichier#ouvrir(java.lang.String)
	 */
	public boolean ouvrir(String chemin) {
		File fichier = new File(chemin);
		
		// turn off the validator
		SAXBuilder builder = new SAXBuilder();
		
		try{
			// build the doc
			Document doc = builder.build(fichier);
			// got Root ?
			Element eroot = doc.getRootElement();
			
			// header
			Element eheader = eroot.getChild("header");
			// + prop
			Element eprop = eheader.getChild("prop");
			if(eprop != null){head.setProp(eprop.getText());}
			// + note
			Element enote  = eheader.getChild("note");
			if(enote != null){head.setNote(enote.getText());}
			// @
			head.setCreationtool(eheader.getAttributeValue("creationtool"));
			head.setCreationtoolversion(eheader.getAttributeValue("creationtoolversion"));
			head.setDatatype(eheader.getAttributeValue("datatype"));
			head.setSegtype(eheader.getAttributeValue("segtype"));
			head.setAdminlang(eheader.getAttributeValue("adminlang"));
			head.setSrclang(eheader.getAttributeValue("srclang"));
			head.setOTmf(eheader.getAttributeValue("o-tmf"));
			
			// body
			Element ebody = eroot.getChild("body");
			// tu
			List etu = ebody.getChildren();
			
			Element tmp, tmp2;
			
			tmp = (Element)(etu.get(0));
			
			textes = new DocumentLang[tmp.getChildren().size()];
			for(int k=0;k<textes.length;k++)
			{
				tmp2 = (Element)(tmp.getChildren().get(k));
				textes[k] = new DocumentLang(tmp2.getAttributeValue("lang", Namespace.XML_NAMESPACE ));
			}
			
			String id, text;
			
			for(int i=0;i<etu.size();i++)
			{
				// tu
				tmp =  (Element)(etu.get(i));
				id = tmp.getAttributeValue("tuid");
				for(int j=0;j<textes.length;j++)
				{
					tmp2 = (Element)(tmp.getChildren().get(j));
					// tuv
					text = tmp2.getChild("seg").getText();
					if(id != null)
					{
						textes[j].add(text,id);
					}
					else
					{
						textes[j].add(text);
					}
				}
			}
			return true;
		}
		catch(JDOMException e)
		{
			JOptionPane.showMessageDialog(parent,
				e.getMessage(),
				"JDOM error",
				JOptionPane.ERROR_MESSAGE);
			
			return false;
		}
		catch(IOException e)
		{			
			JOptionPane.showMessageDialog(parent,
				e.getMessage(),
				"I/O error",
				JOptionPane.ERROR_MESSAGE);
			
			return false;
		}
	}
	
	/**
	 * Retourne l'entte du fichier
	 *
	 * @return entte du fichier.
	 */
	public Header getHeader() {
		return head;
	}	
	
	/**
	 * Retourne les langues contenues par le fichier TMX
	 *
	 * @return	les langues utilises dans le document
	 */
	public String[] getLangs()
	{
		String[] langs = new String[textes.length];
		for(int k=0;k<textes.length;k++)
		{
			langs[k] = new String(textes[k].getLang());
		}
		return langs;
	}
	
	/**
	 * Retourne le nombre de langues du fichier
	 *
	 * @return	taille du fichier (langues)
	 */
	public int getSize()
	{
		return textes.length;
	}
	
	/**
	 * Retourne un Document selon son index
	 *
	 * @param	num	numro du document
	 * @return document slectionn.
	 */
	public DocumentLang getDocument(int num) {
		return textes[num];
	}
	
	/**
	 * Retourne un Document selon sa langue
	 *
	 * @param	lang	langue dsire
	 * @return	document slectionn
	 */
	public DocumentLang getDocument(String lang) {
		for(int k=0;k<textes.length;k++)
		{
			if(textes[k].getLang().equals(lang))
			{
				return textes[k];
			}
		}
		return null;
	}
}
