/*
TmxViewer is a TMX file reader
Copyright (C) 2004 Yoan BLANC <Yoan.Blanc@eiaj.ch>, EIAJ www.eiaj.ch

This program is free software; you can redistribute it and/or modify it under the terms of
the GNU General Public License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA 02111-1307 USA
*/
/**
 *  Header de document Tmx.
 *  
 *  Les lments ne sont pas mis en private
 *  ou dans un tableau car ils peuvent avoir
 *  des restrictions sur leur type, taille, ...
 *  
 *  (http://www.lisa.org/tmx/tmx.htm#header)
 */
public class Header {
	// Tool-specific data or text.
	private String prop;
	private String note;
	private String creationtool;
	private String creationtoolversion;
	private String segtype;
	private String otmf;
	private String srclang;
	private String adminlang;
	private String datatype;
		
	/**
	 * Constructeur (met la valeur datatype  "unknow"
	 */
	public void Header() {
		// valeur par dfaut.
		datatype = "unknow";
	}
	
	/**
	 *  dfinit la valeur &lt;prop&gt; contenue dans le &lt;header6gt; du document
	 *  
	 *  @param	value	valeur de prop
	 */
	public boolean setProp(String value) {
		prop = value;
		return true;
	}
	
	/**
	 *  Retourne la valeur de prop
	 *  
	 *  @return	valeur de prop
	 */
	public String getProp() {
		if(prop != null)
		{
			return prop;
		}
		else
		{
			return "-";
		}
	}
	
	/**
	 *  Dfinit la valeur de la note (commentaire)
	 *  
	 *  @param	value	valeur de note
	 */
	public boolean setNote(String value) {
		note = value;
		return true;
	}
	
	/**
	 *  Retourne la valeur de note
	 *  
	 *  @return	valeur de note
	 */
	public String getNote() {
		if(note != null)
		{
			return note;
		}
		else
		{
			return "-";
		}
	}
	
	/**
	 *  Dfinit l'outil de cration du document
	 *  
	 *  @param	value	Outil de cration du document
	 */
	public boolean setCreationtool(String value) {
		creationtool = value;
		return true;
	}
	
	/**
	 *  Retourne l'outil utilis pour gnr le document
	 *  
	 *  @return outil de cration
	 */
	public String getCreationtool() {
		return creationtool;
	}
	
	/**
	 *  Dfinit la version de l'outil de gnration
	 *  
	 *  @param value Version de l'outil de gnration
	 */
	public boolean setCreationtoolversion(String value) {
		creationtoolversion = value;
		return true;
	}
	
	/**
	 *  Retourne la version de l'outil de cration
	 *  
	 *  @return	version de l'outil de cration
	 */
	public String getCreationtoolversion() {
		return creationtoolversion;
	}
	
	/**
	 *  Dfinit le type de segmentation parmi :
	 *  <ul>
	 *   <li>block,</li>
	 *   <li>paragraph,</li>
	 *   <li>sentence,</li>
	 *   <li>phrase.</li>
	 *  </ul>
	 *  
	 *  @param	value type de segmentation
	 */
	
	public boolean setSegtype(String value) {
		String[] segtypes = {"block","paragraph","sentence","phrase"};
		for(int i=0; i < segtypes.length; i++)
		{
			if(segtypes[i].equals(value))
			{
				segtype = value;
				return true;
			}
		}
		return false;
	}
	
	/**
	 *  Retourne le type de segmentation
	 *  
	 *  @return	type de segmentation
	 */
	public String getSegtype() {
		return segtype;
	}
	
	/**
	 *  Dfinit l'<em xml:lang="en">Original translation memory format</em>.
	 *  
	 *  @param value Original translation memory format
	 */
	public boolean setOTmf(String value) {
		otmf = value;
		return true;
	}
	
	/**
	 *  Retourne l'<em xml:lang="en">Original translation memory format</em>.
	 *  
	 *  @return Original translation memory format
	 */
	public String getOTmf() {
		return otmf;
	}
	
	/**
	 *  Dfinit la langue de la source. La valeur de SrcLang doit
	 *  tre la mme que celle du <code>xml:lang</code> du tuv source sauf
	 *  si la valeur ici est <code>*all*</code>.
	 *  
	 *  @param value langue de la source
	 */
	public boolean setSrclang(String value) {
		srclang = value;
		return true;
	}
	
	/**
	 *  Retourne la langue du document source.
	 *  
	 *  @return langue du document source
	 */
	public String getSrclang() {
		return srclang;
	}
	
	/**
	 *  Dfinit la langue de l'admin, spcifique 
	 *  <code>&lt;note&gt;</code> et <code>&lt;prop&gt;</code>.
	 *  
	 *  @param	value	langue de l'admin
	 */
	public boolean setAdminlang(String value) {
		adminlang = value;
		return true;
	}
	
	/**
	 *  Retourne la langue de l'admin
	 *  
	 *  @return	langue de l'admin
	 */
	public String getAdminlang() {
		return adminlang;
	}
	
	/**
	 *  <p>Dfinit le type de donne contenu dans le fichier.</p>
	 *  <p>liste non exhaustive :</p>
	 *  <dl>
	 *  <dt>unknown</dt><dd>undefined (default)</dd>
	 *  <dt>alptext</dt><dd>WinJoust data.</dd>
	 *  <dt>cdf</dt><dd>Channel Definition Format.</dd>
	 *  <dt>cmx</dt><dd>Corel CMX Format.</dd>
	 *  <dt>cpp</dt><dd>C and C++ style text.</dd>
	 *  <dt>hptag</dt><dd>HP-Tag.</dd>
	 *  <dt>html</dt><dd>HTML, DHTML, etc.</dd>
	 *  <dt>interleaf</dt><dd>Interleaf documents.</dd>
	 *  <dt>ipf</dt><dd>IPF/BookMaster.</dd>
	 *  <dt>java</dt><dd>Java, source and property files.</dd>
	 *  <dt>javascript</dt><dd>JavaScript, ECMAScript scripts.</dd>
	 *  <dt>lisp</dt><dd>Lisp.</dd>
	 *  <dt>mif</dt><dd>Framemaker MIF, MML, etc.</dd>
	 *  <dt>opentag</dt><dd>OpenTag data.</dd>
	 *  <dt>pascal</dt><dd>Pascal, Delphi style text.</dd>
	 *  <dt>plaintext</dt><dd>Plain text.</dd>
	 *  <dt>pm</dt><dd>PageMaker.</dd>
	 *  <dt>rtf</dt><dd>Rich Text Format.</dd>
	 *  <dt>sgml</dt><dd>SGML.</dd>
	 *  <dt>stf-f</dt><dd>S-Tagger for FrameMaker.</dd>
	 *  <dt>stf-i</dt><dd>S-Tagger for Interleaf.</dd>
	 *  <dt>transit</dt><dd>Transit data.</dd>
	 *  <dt>vbscript</dt><dd>Visual Basic scripts.</dd>
	 *  <dt>winres</dt><dd>Windows resources from RC, DLL, EXE.</dd>
	 *  <dt>xml</dt><dd>XML.</dd>
	 *  <dt>xptag</dt><dd>Quark XPressTag.</dd>
	 *  </dl>
	 *  <p>valeur par dfaut : <code>unknown</code></p>
	 *  
	 *  @param value type de donne
	 */
	public boolean setDatatype(String value) {
		datatype = value;
		return true;
	}
	
	/**
	 *  Retourne le type de donne
	 *  
	 *  @return type de donne
	 */
	public String getDatatype() {
		return datatype;
	}
}
