/*
TmxViewer is a TMX file reader
Copyright (C) 2004 Yoan BLANC <Yoan.Blanc@eiaj.ch>, EIAJ www.eiaj.ch

This program is free software; you can redistribute it and/or modify it under the terms of
the GNU General Public License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA 02111-1307 USA
*/
import java.awt.*;
import javax.swing.*;

/**
 * Boite de dialogue d'information sur deux colonnes.
 *
 * Les donnes passes sont affichs dans un tableau 2D.
 */
public class InfoDialog extends JDialog implements Centrable
{
	/// labels affichs dans la boite de dialogue
	private JLabel[] labels;
	
	/**
	 * Constructeur "unique" et principal
	 *
	 * @param parent	lment parent (qui sera responsable d'afficher le dialogue)
	 * @param title	Titre de la boite de dialogue
	 * @param data	Textes affichs dans la boite de dialogue
	 * @param width	Largeur de la boite de dialogue
	 * @param	height	Hauteur de la boite de dialogue
	 */
	public InfoDialog(JFrame parent,String title, String[] data,int width, int height)
	{
		super((Frame)parent,true);
		setTitle(title);
		
		labels = new JLabel[data.length];
		
		buildLabels(data);
		attachLabels();
		
		setSize(width,height);
	}
	
	/**
	 * Labelisation des donnes textes.
	 *
	 * @param data	Textes  labelis
	 */
	private void buildLabels(String[] data)
	{
		for(int i=0;i<data.length;i++)
		{
			labels[i] = new JLabel(data[i]);
		}
	}
	
	/**
	 * Ajout des labels a la grille d'affichage.
	 */
	private void attachLabels()
	{
		JPanel grid = new JPanel(new GridLayout(labels.length/2,2,2,2));
		
		for(int i=0; i<labels.length; i++)
		{
			grid.add(labels[i]);
		}
		
		getContentPane().add(grid);
	}
	
	/**
	 *  Centre la fentre au milieu de l'cran.
	 *
	 * @see Centrable#centrer()
	 */
	public void centrer() {
		Dimension ecran = Toolkit.getDefaultToolkit().getScreenSize();
		setLocation((ecran.width - getSize().width)/2,(ecran.height - getSize().height)/2);
	}
}