/*
TmxViewer is a TMX file reader
Copyright (C) 2004 Yoan BLANC <Yoan.Blanc@eiaj.ch>, EIAJ www.eiaj.ch

This program is free software; you can redistribute it and/or modify it under the terms of
the GNU General Public License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA 02111-1307 USA
*/
import javax.swing.*;
import java.awt.event.*;

public class Menu extends JMenuBar {
	/// Menu "File"
	private JMenu fileMenu;
	/// Menu "About"
	private JMenu aboutMenu;
	/// lments du menu "File"
	private String[] fileItems;
	/// lments du menu "About"
	private String[] aboutItems;
	/**
	 * Construit les menus
	 */
	public Menu()
	{
		fileMenu = new JMenu("File");
		fileItems = new String[] {"Open","Close","Info","Quit"};
		
		aboutMenu = new JMenu("About");
		aboutItems = new String[] {"Author","Copyright"};
		
		for(int i=0; i< fileItems.length; i++)
		{
			JMenuItem tmpItem = new JMenuItem(fileItems[i]);
			tmpItem.setEnabled(false);
			fileMenu.add(tmpItem);
		}
		fileMenu.insertSeparator(fileItems.length - 2); // before "Info"
		fileMenu.insertSeparator(fileItems.length); // before "Quit"
		
		for(int i=0; i< aboutItems.length; i++)
		{
			JMenuItem tmpItem = new JMenuItem(aboutItems[i]);
			tmpItem.setEnabled(false);
			aboutMenu.add(tmpItem);
		}
		
		// add the menus
		add(fileMenu);
		add(aboutMenu);
	}
	
	/**
	 * Ajoute un couteur permettant d'ouvrir un fichier
	 *
	 * @param ecoute	couteur explorateur
	 */
	public void addExplorateurEcouteur(ExplorateurDeFichier ecoute)
	{
		fileMenu.getItem(0).addActionListener(ecoute);
		fileMenu.getItem(0).setEnabled(true);
	}

	/**
	 * Ajoute un couteur permettant de fermer un fichier
	 *
	 * @param ecoute	couteur de fermeture
	 */
	public void addCloseEcouteur(CloseEcouteur ecoute)
	{
		fileMenu.getItem(1).addActionListener(ecoute);
		fileMenu.getItem(1).setEnabled(true);
	}
	
	/**
	 * Supprime les couteurs lis  l'action de fermeture
	 */
	public void disableCloseEcouteur()
	{
		ActionListener[] al = fileMenu.getItem(1).getActionListeners();
		for(int i=0; i<al.length; i++)
		{
			fileMenu.getItem(1).removeActionListener(al[i]);
		}
		
		fileMenu.getItem(1).setEnabled(false);
	}
	
	/**
	 * Ajoute un couteur permettant d'afficher les informations d'un fichier
	 *
	 * @param ecoute	couteur d'information
	 */
	public void addInfoEcouteur(MenuInfoEcouteur ecoute)
	{
		// info
		fileMenu.getItem(3).addActionListener(ecoute);
		fileMenu.getItem(3).setEnabled(true);
	}
	
	/**
	 * Supprime les couteurs d'informations
	 */
	public void disableInfoEcouteur()
	{
		ActionListener[] al = fileMenu.getItem(3).getActionListeners();
		for(int i=0; i<al.length; i++)
		{
			fileMenu.getItem(3).removeActionListener(al[i]);
		}
		
		fileMenu.getItem(3).setEnabled(false);
	}
	
	/**
	 * Ajoute un couteur permettant d'ouvrir un fichier
	 *
	 * @param ecoute	couteur explorateur
	 */
	public void addFermetureEcouteur(FermetureEcouteur ecoute)
	{
		fileMenu.getItem(5).addActionListener(ecoute);
		fileMenu.getItem(5).setEnabled(true);
	}

	/**
	 * Ajoute un couteur permettant d'afficher les informations lies  l'auteur
	 *
	 * @param ecoute	couteur afficheur d'information auteur.
	 */
	public void addAboutAuthorEcouteur(MenuDialogEcouteur ecoute)
	{
		aboutMenu.getItem(0).addActionListener(ecoute);
		aboutMenu.getItem(0).setEnabled(true);
	}
	
	/**
	 * Ajoute un couteur permettant d'afficher les informations lies aux droits d'auteur du logiciel
	 *
	 * @param ecoute	couteur afficheur de copyright
	 */
	public void addCopyrightEcouteur(MenuDialogEcouteur ecoute)
	{
		aboutMenu.getItem(1).addActionListener(ecoute);
		aboutMenu.getItem(1).setEnabled(true);
	}
}
