/*
TmxViewer is a TMX file reader
Copyright (C) 2004 Yoan BLANC <Yoan.Blanc@eiaj.ch>, EIAJ www.eiaj.ch

This program is free software; you can redistribute it and/or modify it under the terms of
the GNU General Public License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA 02111-1307 USA
*/
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
 * couteur abstrait affichant une boite de dialogue.
 */
public abstract class MenuEcouteur implements ActionListener
{
	private JFrame parent;
	private String title;
	private int width;
	private int height;
	
	/**
	 * Construit un couteur affichant une boite de dialogue
	 *
	 * @param	parent	JFrame principale (parente)
	 * @param title	Titre de la boite de dialogue
	 * @param width	largeur de la boite de dialogue
	 * @param height	hauteur de la boite de dialogue
	 */
	public MenuEcouteur(JFrame parent, String title, int width, int height)
	{
		this.parent = parent;
		this.width = width;
		this.height = height;
		this.title = title;
	}

	
	/**
	 * Action
	 *
	 * @param	e	vnement action.
	 */
	public abstract void actionPerformed(ActionEvent e);
	
	/**
	 * Affiche la bote de dialogue avec le texte entr.
	 *
	 * @param texte de la boite de dialogue
	 */
	public void showInfo(String[] texte)
	{
		InfoDialog info = new InfoDialog(parent,title,texte,width,height);
		info.centrer();
		info.setVisible(true);
	}
	
	/**
	 * Retourne la largeur
	 *
	 * @return largeur
	 */
	public int getWidth()
	{
		return width;
	}
	
	/**
	 * Retourne la hauteur
	 *
	 * @return hauteur
	 */
	public int getHeight()
	{
		return height;
	}
	
	/**
	 * Retourne la fentre principale parente
	 *
	 * @return fentre principal
	 */
	public JFrame getParent()
	{
		return parent;
	}
	
	/**
	 * Retourne le titre
	 *
	 * @return titre
	 */
	public String getTitle()
	{
		return title;
	}
}