/*
TmxViewer is a TMX file reader
Copyright (C) 2004 Yoan BLANC <Yoan.Blanc@eiaj.ch>, EIAJ www.eiaj.ch

This program is free software; you can redistribute it and/or modify it under the terms of
the GNU General Public License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA 02111-1307 USA
*/
import javax.swing.*;
import java.util.ArrayList;

public class TmxManager
{
	private MainJFrame tmxv;
	private Menu me;
	
	private int[] sizeInit;
		
	private String title;
	private String[] infoAuthor;
	private String[] infoCopyright;
	
	private ArrayList tablist;
	
	private TmxTabbed tabs;
	private ImageIcon tabIcon;
	
	/**
	 * Construit le gestionnaire de fichier TMX
	 *
	 * @param title Titre de la fentre
	 * @param width Largeur de la fentre
	 * @param height Hauteur de la fentre
	 * @param infoAuthor Informations lies  l'auteur
	 * @param infoCopyright Informations lies au copyright du logiciel
	 */
	public TmxManager(String title, int width, int height, String[] infoAuthor, String[] infoCopyright)
	{
		this.title = title;
		this.infoAuthor = infoAuthor;
		this.infoCopyright = infoCopyright;
		
		tmxv = new MainJFrame(title);
		me = new Menu();
		tabs = new TmxTabbed();
		tabIcon = new ImageIcon("../img/tab.gif");
		sizeInit = new int[]{width,height};
		tablist = new ArrayList();
		
		EcouteursPrincipaux();
		
		tmxv.setJMenuBar(me);
		tmxv.getContentPane().add(tabs);
		tmxv.setSize(sizeInit[0],sizeInit[1]);
		tmxv.centrer();
		tmxv.setVisible(true);
		tabs.setVisible(true);
	}
	
	/**
	 * Retourne la fentre principale
	 *
	 * @return fentre principale
	 */
	public MainJFrame getMainJFrame()
	{
		return tmxv;
	}
	
	/**
	 * Ouvre un nouvelle onglet avec le fichier choisit.
	 *
	 * @param url	addresse du fichier  ouvrir
	 */
	public void ouvrir(String url)
	{
		TmxTab tab = new TmxTab(tmxv, url);
		
		tablist.add(tab);
		tabs.addTab(tab.getFileName(),tabIcon,tab.getComponent(),url);
	}
	
	/**
	 * Ferme un fichier, donc supprime l'onglet.
	 *
	 * @param index lment  fermer
	 */
	public void fermer(int index)
	{
		tablist.remove(index);
		tabs.removeTabAt(index);
	}
	
	/**
	 * Retourne les informations du fichier  l'onglet n index.
	 *
	 * @param index	n de l'onglet
	 * @return Informations du fichier Tmx
	 */
	public String[] getTabInfo(int index)
	{
		return ((TmxTab)tablist.get(index)).info();
	}
	
	/**
	 * lments du menu lis au programme mme.
	 */
	private void EcouteursPrincipaux()
	{
		// cration des couteurs
		MenuDialogEcouteur Aecoute = new MenuDialogEcouteur((JFrame)tmxv,"Author",infoAuthor,350,100);
		MenuDialogEcouteur Cecoute = new MenuDialogEcouteur((JFrame)tmxv,"Copyright",infoCopyright,350,100);
		
		ExplorateurDeFichier Eecoute = new ExplorateurDeFichier(this);
		FermetureEcouteur Fecoute = new FermetureEcouteur();
		
		CloseEcouteur Clecoute = new CloseEcouteur(this,tabs);
		MenuInfoEcouteur Iecoute = new MenuInfoEcouteur((JFrame)tmxv,"Informations",this,tabs,350,150);
		
		// ajout des couteurs au menu
		me.addAboutAuthorEcouteur(Aecoute);
		me.addCopyrightEcouteur(Cecoute);
		
		me.addExplorateurEcouteur(Eecoute);
		me.addFermetureEcouteur(Fecoute);
		
		me.addCloseEcouteur(Clecoute);
		me.addInfoEcouteur(Iecoute);
	}
}