/*
TmxViewer is a TMX file reader
Copyright (C) 2004 Yoan BLANC <Yoan.Blanc@eiaj.ch>, EIAJ www.eiaj.ch

This program is free software; you can redistribute it and/or modify it under the terms of
the GNU General Public License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
MA 02111-1307 USA
*/
import javax.swing.*;

/**
 * Onglet TMX
 */
public class TmxTab
{
	private JFrame parent;
	private String url;
	
	private FichierTmx tmxf;
	
	private TmxDisplay[] zones;
	private JScrollPane[] scrolls;
	private JSplitPane[] splits;
		
	private int size;
		
	private LinkEcouteur ecouteur;
	
	/**
	 * Constructeur de l'onglet
	 *
	 * @param parent	lment grant le systmee
	 * @param url addresse du fichier  ouvrir
	 */
	public TmxTab(JFrame parent, String url)
	{
		this.parent = parent;
		this.url = url;
		
		tmxf = new FichierTmx(parent);
		
		if(!tmxf.ouvrir(url))
			return;
		
		size = tmxf.getSize();
		
		zones = new TmxDisplay[size];
		scrolls = new JScrollPane[size];
		splits = new JSplitPane[((size>1) ? size : 1)];
		
		ecouteur = new LinkEcouteur(zones);
		
		for(int i=0; i<size; i++)
		{
			zones[i] = new TmxDisplay(tmxf.getDocument(i));
			zones[i].addHyperlinkListener(ecouteur);
			scrolls[i] = new JScrollPane(zones[i], JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_NEVER );
		}
		

		for(int i=0; i<size - 1;i++)
		{
			if(i==0)
			{
				splits[i] = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, scrolls[i], scrolls[i+1]);
			}
			else
			{
				splits[i] = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, splits[i-1], scrolls[i+1]);
			}
			splits[i].setOneTouchExpandable(true);
			splits[i].setResizeWeight((i+1)/(double)(i+2));
			splits[i].setDividerSize(4);
		}
	}
	
	/**
	 * Retourne le composant  afficher dans l'onglet
	 *
	 * @return Composant principal
	 */
	public JComponent getComponent()
	{
		if(size > 1)
		{
			return splits[size-2];
		}
		else
		{
			return scrolls[size-1];
		}
	}
	
	/**
	 * Obtention du nom du fichier
	 * 
	 * @return nom du fichier gnr  partir de l'url de celui-ci
	 */
	public String getFileName()
	{
		// windows mode
		String[] elem = url.split("\\u005C"); // == "\"
		if(elem.equals(url))
		{
			// unix mode
			elem = url.split("/");
		}
		
		return elem[elem.length-1];
	}
	
	/**
	 * Retourne un tableau d'information destin 
	 *
	 * @see InfoDialog
	 * @return	tableau contenant le nom et la valeur des lments du <code>header</code>
	 */
	public String[] info()
	{
		Header head = tmxf.getHeader();
		String[] data = new String[18];
		
		data[0] = "creation tool : " ;
		data[1] = head.getCreationtool();
		data[2] = "creation tool version : ";
		data[3] = head.getCreationtoolversion();
		data[4] = "data type : ";
		data[5] = head.getDatatype();
		data[6] = "seg type : ";
		data[7] = head.getSegtype();
		data[8] = "admin lang : ";
		data[9] = head.getAdminlang();
		data[10] = "src lang : ";
		data[11] = head.getSrclang();
		data[12] = "o-tmf : ";
		data[13] = head.getOTmf();
		data[14] = "prop : ";
		data[15] = head.getProp();
		data[16] = "note : ";
		data[17] = head.getNote();
		
		return data;
	}
}